@@ -54,10 +54,25 @@ GQuark rsvg_error_quark (void) G_GNUC_CONST;
 /**
  * The RsvgHandle is an object representing the parsed form of a SVG
  */
-typedef struct RsvgHandle RsvgHandle;
-typedef struct RsvgHandleClass RsvgHandleClass;
+typedef struct _RsvgHandle RsvgHandle;
+typedef struct RsvgHandlePrivate RsvgHandlePrivate;
+typedef struct _RsvgHandleClass RsvgHandleClass;
 typedef struct _RsvgDimensionData RsvgDimensionData;
 
+struct _RsvgHandleClass {
+	GObjectClass parent;
+
+	gpointer _abi_padding[15];
+};
+
+struct _RsvgHandle {
+	GObject parent;
+
+	RsvgHandlePrivate *priv;
+
+	gpointer _abi_padding[15];
+};
+
 /* RsvgDimensionData
  */
 struct _RsvgDimensionData {
@@ -135,7 +150,7 @@ void        rsvg_handle_free              (RsvgHandle      *handle);
  * @height: the output height the SVG should be
  * @user_data: user data
  *
- * Deprecated: Set up a cairo matrix and use rsvg_cairo_render() instead.
+ * Deprecated: Set up a cairo matrix and use rsvg_handle_render_cairo() instead.
  */
 typedef void (* RsvgSizeFunc) (gint     *width,
 							   gint     *height,
